# DBND Snowflake

## The plugin

`dbnd-snowflake` Log preview, schema, size and system resource usage for Snowflake tables.

### What does it do?

It uses system Snowflake tables and views to fetch meta data.

### Installation

```bash
pip install dbnd-snowflake
```
